import { AfterViewInit, Component, DoCheck, ElementRef, EventEmitter, HostListener, Input, IterableDiffer, IterableDiffers, Output, QueryList, ViewChildren } from '@angular/core';
import { Message } from '../../../models/message';

@Component({
  selector: 'app-feed',
  standalone: false,
  templateUrl: './feed.component.html',
  styleUrl: './feed.component.scss'
})
export class FeedComponent implements AfterViewInit {
  @Input('messages') public messages?: Message[];
  @Output('outOfMessages') public outOfMessages: EventEmitter<void> = new EventEmitter<void>();

  constructor(private element: ElementRef<HTMLElement>) { }

  ngAfterViewInit(): void {
    this.scrollToBottom();
  }

  private isAtBottom(): boolean {
    let element = this.element.nativeElement;
    return Math.abs(element.scrollHeight - element.clientHeight - element.scrollTop) <= 100;
  }

  private isAtTop(): boolean {
    let element = this.element.nativeElement;
    return element.scrollTop == 0;
  }

  private scrollToBottom(): void {
    setTimeout(() => this.element.nativeElement.scrollTop = this.element.nativeElement.scrollHeight, 100);
  }

  // handles scroll to bottom events from the chat component when a new message arrives
  public ScrollEventHandler(): void {
    if (this.isAtBottom()) this.scrollToBottom();
  }

  @HostListener('scroll')
  private detectOutOfMessages(): void {
    if (this.isAtTop()) {
      this.outOfMessages.emit();
    }
  }

  public ScrollToMessage(channelID: number, messageID: number): void {
    setTimeout(() => {
      let id = `#c${channelID}m${messageID}`;

      let target = this.element.nativeElement.querySelector(id) as HTMLDivElement | null;
      if (!target) return;

      this.element.nativeElement.scrollTo({
        top: target.offsetTop - target.offsetHeight,
        behavior: "instant"
      });
    }, 100);
  }
}
